#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hpack
version:              0.38.0
visibility:           public
id:                   hpack-0.38.0-7wmKCzrQocH4fgzex9Cczn
key:                  hpack-0.38.0-7wmKCzrQocH4fgzex9Cczn
license:              MIT
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/hpack#readme
synopsis:             A modern format for Haskell packages
description:          See README at <https://github.com/sol/hpack#readme>
category:             Development
abi:                  d83da55b61506cf5e7ab71f6321e930b
exposed:              True
exposed-modules:
    Hpack Hpack.Config Hpack.Error Hpack.Render Hpack.Yaml

hidden-modules:
    Data.Aeson.Config.FromValue Data.Aeson.Config.Key
    Data.Aeson.Config.KeyMap Data.Aeson.Config.Parser
    Data.Aeson.Config.Types Data.Aeson.Config.Util Hpack.CabalFile
    Hpack.Defaults Hpack.Haskell Hpack.License Hpack.Module
    Hpack.Options Hpack.Render.Dsl Hpack.Render.Hints
    Hpack.Syntax.BuildTools Hpack.Syntax.Defaults
    Hpack.Syntax.Dependencies Hpack.Syntax.DependencyVersion
    Hpack.Syntax.Git Hpack.Syntax.ParseDependencies Hpack.Utf8
    Hpack.Util Imports Path Paths_hpack

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hpack-0.38.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hpack-0.38.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hpack-0.38.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hpack
hs-libraries:         HShpack-0.38.0-7wmKCzrQocH4fgzex9Cczn
depends:
    Cabal-3.10.3.0 Glob-0.10.2-LQYbd0wNnOB58MUTK2wq9r
    aeson-2.2.2.0-Bvq1RZLTB982HJyF7e96XU base-4.18.2.1
    bifunctors-5.6.3-FTVXhqzScTfLrb1caTdfv2 bytestring-0.11.5.3
    containers-0.6.7 crypton-1.0.4-GFZcLsOAlSN77AqvXDOpN4
    deepseq-1.4.8.1 directory-1.3.8.5 filepath-1.4.300.1
    http-client-0.7.19-BV4AT2QZinhAZt9DyDMIrY
    http-client-tls-0.3.6.4-4PkwIHdSyLZEv9DDXogskJ
    http-types-0.12.4-BfnwqLIFvgHNb88uBZwW9
    infer-license-0.2.0-7xNcfQBh5NTGsadg2RwFbG mtl-2.3.1 pretty-1.1.3.6
    scientific-0.3.8.1-25vWQKW70jDDFFn5H243Ra text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-ITIVaOGw28dDFkmcPJu0s3
    vector-0.13.2.0-9FXioZw2Nye8eueJzIuHK4
    yaml-0.11.11.2-FLCCKo0n0nJK5o0PhDW0y0

haddock-interfaces:   /usr/share/doc/haskell-hpack/html/hpack.haddock
haddock-html:         /usr/share/doc/haskell-hpack/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

